@@ -30,7 +30,6 @@ class ctx:
 
 class MiscTest(TemplateTest):
     def test_crlf_linebreaks(self):
-
         crlf = r"""
 <%
     foo = True
@@ -940,18 +939,15 @@ class ControlTest(TemplateTest):
     %endfor
 """
         )
-        assert (
-            result_lines(
-                t.render(
-                    y=[
-                        {"test": "one"},
-                        {"foo": "bar"},
-                        {"foo": "bar", "test": "two"},
-                    ]
-                )
+        assert result_lines(
+            t.render(
+                y=[
+                    {"test": "one"},
+                    {"foo": "bar"},
+                    {"foo": "bar", "test": "two"},
+                ]
             )
-            == ["yes x has test", "no x does not have test", "yes x has test"]
-        )
+        ) == ["yes x has test", "no x does not have test", "yes x has test"]
 
     def test_blank_control_1(self):
         self._do_memory_test(
@@ -1167,7 +1163,6 @@ class GlobalsTest(TemplateTest):
 
 class RichTracebackTest(TemplateTest):
     def _do_test_traceback(self, utf8, memory, syntax):
-
         if memory:
             if syntax:
                 source = (
